// 01HZT59RTH4R6P1TYE6NMAFYEP 018FF454-E351-260D-60EB-CE3568A7F9D6

use axum::{
    extract::{Path, State},
    routing::get,
    Router,
};
use maud::{html, Markup};
use sqlx::query;
use ulid::Ulid;
use uuid::Uuid;

use super::{page, Breadcrumb, BC_INDEX};
use crate::{app::SharedState, error::AppError};

pub(super) fn router() -> Router<SharedState> {
    Router::new().route("/:id", get(show_paste))
}

const BC_PASTES_PUBLIC: Breadcrumb = Breadcrumb::new_static("Pastes", "/p");

async fn show_paste(
    Path(id): Path<Ulid>,
    State(SharedState { db, .. }): State<SharedState>,
) -> Result<Markup, AppError> {
    match query!(
        "SELECT title, content FROM paste WHERE id = $1",
        Uuid::from(id)
    )
    .fetch_optional(&db)
    .await?
    {
        Some(r) => Ok(page(
            &r.title,
            &[BC_INDEX, BC_PASTES_PUBLIC],
            html! {
                pre class="p-4 border border-bd-base rounded-xl" { (r.content) }
            },
        )),
        None => Err(AppError::PasteNotFound(id)),
    }
}
