use axum::{
    extract::{Path, State},
    response::Redirect,
    routing::get,
    Router,
};
use sqlx::query;

use super::SharedState;
use crate::error::AppError;

pub fn router() -> Router<SharedState> {
    Router::new().route("/:slug", get(redirect_link))
}

async fn redirect_link(
    State(SharedState { db, .. }): State<SharedState>,
    Path(slug): Path<String>,
) -> Result<Redirect, AppError> {
    match query!("SELECT destination FROM link WHERE slug = $1", slug)
        .fetch_optional(&db)
        .await?
    {
        Some(r) => Ok(Redirect::temporary(&r.destination)),
        None => Err(AppError::LinkNotFoundSlug(slug)),
    }
}
